@@ -39,8 +39,8 @@ def __return_wrapper(resp):
 
 def _init():
     session = requests.Session()
-    session.mount('http://', HTTPAdapter(max_retries=Config.connection_retries))
-    session.mount('https://', HTTPAdapter(max_retries=Config.connection_retries))
+    session.mount('http://', HTTPAdapter(max_retries=int(Config.connection_retries)))
+    session.mount('https://', HTTPAdapter(max_retries=int(Config.connection_retries)))
     global _session
     _session = session
 
